@@ -1,7 +1,10 @@
-package Net::Delicious::User;
+# $Id: User.pm,v 1.3 2005/12/17 19:04:14 asc Exp $
 use strict;
 
-# $Id: User.pm,v 1.2 2005/04/05 15:56:50 asc Exp $
+package Net::Delicious::User;
+use base qw (Net::Delicious::Object);
+
+$Net::Delicious::User::VERSION = '0.94';
 
 =head1 NAME
 
@@ -39,8 +42,6 @@ objects outside of I<Net::Delicious> itself.
 
 =cut
 
-$Net::Delicious::User::VERSION = '0.1';
-
 use overload q("") => sub { shift->name() };
 
 =head1 PACKAGE METHODS
@@ -53,16 +54,7 @@ Returns a I<Net::Delicious::User> object. Woot!
 
 =cut
 
-sub new {
-    my $pkg  = shift;
-    my $args = shift;
-
-    my %self = map {
-	$_ => $args->{ $_ }
-    } qw ( name );
-
-    return bless \%self, $pkg;    
-}
+# Defined in Net::Delicious::Object
 
 =head1 OBJECT METHODS
 
@@ -79,13 +71,26 @@ sub name {
     return $self->{name};
 }
 
+=head2 $obj->as_hashref()
+
+Return the object as a hash ref safe for serializing and re-blessing.
+
+=cut
+
+# Defined in Net::Delicious::Object
+
+sub _properties {
+        my $pkg = shift;
+        return qw ( name );
+}
+
 =head1 VERSION
 
-0.1
+0.94
 
 =head1 DATE
 
-$Date: 2005/04/05 15:56:50 $
+$Date: 2005/12/17 19:04:14 $
 
 =head1 AUTHOR
 
